@@ -1,7 +1,9 @@
 #!/usr/bin/env perl
 
+use 5.010;
+use strict;
 use warnings;
-use v5.22;
+
 binmode STDOUT, ":utf8";
 
 use Data::Gimei;
